@@ -31,12 +31,3 @@ class datetime(original_datetime):
         of 'now'.
         """
         cls.set_now(None)
-
-def time():
-    if datetime._current_now is None:
-        return original_time()
-    now = datetime.now()
-    return time.mktime(now.timetuple) + now.microsecond / 1000000
-
-time.time = time
-
